<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Wybierz czcionki terminalu</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Zakładki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Wciśnij &quot;%1&quot; aby zobaczyć terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Następna karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Poprzednia karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Move Tab &amp;Left</source>
        <translation>Przesuń kartę w &amp;lewo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Move Tab &amp;Right</source>
        <translation>Przesuń kartę w &amp;prawo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Wyczyść aktywny terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Keep window open when it loses focus</source>
        <translation>Pozostaw okno otwarte po przełączeniu skupienia na inne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Poprzednia karta w historii</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Następna karta w historii</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Tab</source>
        <translation>Karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Go to</source>
        <translation>Przejdź do</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>Podzielony &amp;widok góra-dół</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>Podzielony wi&amp;dok lewo-prawo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>&amp;Close Subterminal</source>
        <translation>&amp;Zamknij podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Górny podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Dolny podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Lewy podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Prawy podterm&amp;inal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Copy &amp;Selection</source>
        <translation>Skopiu&amp;j zaznaczony tekst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Paste Clip&amp;board</source>
        <translation>Wklej z &amp;głównego schowka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>Paste S&amp;election</source>
        <translation>Wklej ze sc&amp;howka zaznaczenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Zoom &amp;in</source>
        <translation>Po&amp;większ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Zoom &amp;out</source>
        <translation>Z&amp;mniejsz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Zoom rese&amp;t</source>
        <translation>Zwykła wielkość tekst&amp;u</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Find...</source>
        <translation>Szuka&amp;j…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Handle history...</source>
        <translation>Przetwarzaj historię...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>&amp;Save Session</source>
        <translation>Z&amp;apisz sesję</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;Load Session</source>
        <translation>Wcz&amp;ytaj sesję</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Zmień widoczność menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Rename session</source>
        <translation>Zmień nazwę sesji</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nowa karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nowa karta z sza&amp;blonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 p&amp;oziome terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 p&amp;ionowe terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 te&amp;rminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;Close Tab</source>
        <translation>Zam&amp;knij kartę</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;New Window</source>
        <translation>Nowe &amp;okno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>&amp;Preferences...</source>
        <translation>Pr&amp;eferencje…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Ukryj ob&amp;ramowanie okna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Pokaż &amp;pasek kart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Toggle Bookmarks</source>
        <translation>Przełącz zakładki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>&amp;Bottom</source>
        <translation>Na &amp;dole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>&amp;Top</source>
        <translation>Na &amp;górze</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>&amp;Right</source>
        <translation>Po p&amp;rawej</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>&amp;Left</source>
        <translation>Po &amp;lewej</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>&amp;Tabs Layout</source>
        <translation>P&amp;ołożenie paska kart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;None</source>
        <translation>&amp;Nigdzie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Położenie paska prze&amp;wijania</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;BlockCursor</source>
        <translation>Pros&amp;tokąt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Pod&amp;kreślenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>&amp;IBeamCursor</source>
        <translation>Pionowa &amp;linia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Kształt kursoru tekstowego</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>A process is running.</source>
        <translation>Proces jest uruchomiony.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Exit QTerminal</source>
        <translation>Zamknij QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Are you sure you want to exit?</source>
        <translation>Na pewno chcesz zamknąć QTerminal?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Lekki, wieloplatformowy emulator terminala</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>2013-2025</source>
        <translation>2013-2025</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>LXQt Project</source>
        <translation>Projekt LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Development: </source>
        <translation>Rozwój: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Ustawienia terminalu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="38"/>
        <location filename="../forms/propertiesdialog.ui" line="729"/>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="56"/>
        <source>Dropdown</source>
        <translation>Opuszczanie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="65"/>
        <source>Bookmarks</source>
        <translation>Zakładki</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="556"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Ukryj pasek kart, gdy jest jedna karta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="181"/>
        <source>Color scheme</source>
        <translation>Paleta kolorów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="207"/>
        <source>Scrollbar position</source>
        <translation>Położenie paska przewijania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="370"/>
        <source>Start with preset:</source>
        <translation>Szablon początkowy:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="287"/>
        <source>Terminal transparency</source>
        <translation>Przezroczystość terminalu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>None (single terminal)</source>
        <translation>Żaden (pojedynczy terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="386"/>
        <source>2 terminals horizontally</source>
        <translation>2 poziome terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="391"/>
        <source>2 terminals vertically</source>
        <translation>2 pionowe terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="396"/>
        <source>4 terminals</source>
        <translation>4 terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="297"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="135"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="171"/>
        <source>&amp;Change...</source>
        <translation>&amp;Zmień…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>Tabs position</source>
        <translation>Położenie kart</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Widget style</source>
        <translation>Styl widżetów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="512"/>
        <source>Show the menu bar</source>
        <translation>Pokazuj pasek menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="233"/>
        <source>Cursor shape</source>
        <translation>Kształt kursora</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="270"/>
        <source>Enable bi-directional text support</source>
        <translation>Włącz wsparcie dwukierunkowego tekstu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="313"/>
        <source>Background image:</source>
        <translation>Obraz w tle:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Select</source>
        <translation>Zaznacz</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="263"/>
        <source>Show terminal size on resize</source>
        <translation>Pokazuj rozmiar terminala po jego zmianie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="563"/>
        <source>Fixed tab width:</source>
        <translation>Stała szerokość kart:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="414"/>
        <location filename="../forms/propertiesdialog.ui" line="573"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="536"/>
        <source>Show close button on each tab</source>
        <translation>Pokazuj przycisk zamykania na każdej karcie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Terminal margin</source>
        <translation>Granica terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="280"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Użyj znaków rysunkowych zawartych w czcionce</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="519"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Akceleratory są aktywowane przez klawisz Alt i mogą zakłócać pracę terminala.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="522"/>
        <source>No menu bar accelerator</source>
        <translation>Brak akceleratora paska menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="922"/>
        <source>Emulation</source>
        <translation>Emulacja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Action after paste</source>
        <translation>Działanie po wklejeniu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Confirm multiline paste</source>
        <translation>Potwierdzaj wklejanie wielu linii</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="835"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Usuwaj znaki nowej linii z końca wklejanego tekstu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="849"/>
        <source>Open new terminals in current working directory</source>
        <translation>Nowe terminale otwieraj w bieżącym katalogu roboczym</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="590"/>
        <source>Save Size when closing</source>
        <translation>Zapisz rozmiar podczas zamykania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="583"/>
        <source>Save Position when closing</source>
        <translation>Zapisz pozycję podczas zamykania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Unlimited history</source>
        <translation>Nieograniczona historia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="735"/>
        <source>History size (in lines)</source>
        <translation>Liczba linii historii</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <source>Default $TERM</source>
        <translation>Domyślny $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="609"/>
        <source>Start with this size:</source>
        <translation>Rozpocznij z rozmiarem:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="334"/>
        <source>Background mode:</source>
        <translation>Tryb tła:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="342"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Stretch</source>
        <translation>Rozciągnij</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="352"/>
        <source>Zoom</source>
        <translation>Powiększ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="357"/>
        <source>Fit</source>
        <translation>Dopasuj</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="362"/>
        <source>Center</source>
        <translation>Wyśrodkuj</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="277"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Określ, czy znaki powinny być rysowane wewnętrznie przez QTerminal, czy za pomocą bazowych bibliotek renderowania czcionek.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="253"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Przełącza użycie pogrubionej czcionki do renderowania intensywnych kolorów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="256"/>
        <source>Use bold font face for intense colors</source>
        <translation>Użyj pogrubionej czcionki do intensywnych kolorów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="529"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Ukryj obramowanie okna</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Jakie zachowanie emulować. Pamiętaj, że nie musi to odpowiadać Twojemu systemowi operacyjnemu.&lt;/p&gt;&lt;p&gt;Jeśli nie masz pewności, użyj trybu &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>To polecenie zostanie uruchomione z argumentem zawierającym nazwę pliku tymczasowego zawierającego historię przewijania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="912"/>
        <source>Handle history command</source>
        <translation>Polecenie obsługi historii</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="616"/>
        <location filename="../forms/propertiesdialog.ui" line="630"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Get current size</source>
        <translation>Uzyskaj obecny rozmiar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="859"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Otwórz nową kartę po prawej od aktywnej</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="856"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Po odznaczeniu tej opcji nowa karta zostanie otwarta jako pierwsza od prawej</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="546"/>
        <source>Close tab on middle-click</source>
        <translation>Zamknij kartę kliknięciem środkowym przyciskiem</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="821"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Wymuś wyłączenie trybu wklejania w nawiasach</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="775"/>
        <source>Word selection characters</source>
        <translation>Znaki zaznaczania słów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="246"/>
        <source>Blinking cursor</source>
        <translation>Migający kursor</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="421"/>
        <source>Current Terminal</source>
        <translation>Bieżący terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Draw a border</source>
        <translation>Rysuj obramowanie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="434"/>
        <source>Set the current terminal on mouseover</source>
        <translation>Ustaw bieżący terminal po najechaniu myszką</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="441"/>
        <source>Change window title based on the terminal</source>
        <translation>Zmień tytuł okna na podstawie terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="448"/>
        <source>Change window icon based on the terminal</source>
        <translation>Zmień ikonę okna na podstawie terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="597"/>
        <source>Save State when closing</source>
        <translation>Zapisz stan podczas zamykania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Zaznaczając tekst według słów, oprócz znaków alfanumerycznych uwzględniaj te znaki jako część słów</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="785"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="792"/>
        <source>Mouse cursor hiding delay</source>
        <translation>Opóźnienie ukrywania kursora myszy</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="799"/>
        <source>No hiding</source>
        <translation>Bez ukrywania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source> sec</source>
        <translation> sek.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="818"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Tryb wklejania w nawiasach jest pomocny przy wklejaniu wielu linii tekstu.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="842"/>
        <source>Prompt on closing with a running process</source>
        <translation>Monituj przy zamykaniu z uruchomionym procesem</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="866"/>
        <source>Audible bell</source>
        <translation>Słyszalny dzwonek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Aby edytować skrót:
1. Kliknij dwa razy jego przycisk
2. Naciśnij żądaną kombinację klawiszy, a następnie puść wszystkie klawisze
3. Kliknij na skrót i naciśnij Enter

Aby usunąć/wyłączyć skrót, przy drugim punkcie naciśnij tylko klawisz modyfikatora (np. Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="985"/>
        <source>Shortcut</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="990"/>
        <source>Key</source>
        <translation>Przycisk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1002"/>
        <source>Show on start</source>
        <translation>Uruchom otwarty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1009"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Przycisk blokowania jest wyświetlany na poziomym pasku kart</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1012"/>
        <source>Keep window open when it loses focus</source>
        <translation>Pozostaw okno otwarte po utracie skupienia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1030"/>
        <source>Height</source>
        <translation>Wysokość</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1040"/>
        <location filename="../forms/propertiesdialog.ui" line="1063"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1053"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1083"/>
        <source>Shortcut:</source>
        <translation>Skrót:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1092"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>Uwaga: w Wayland należy dodać skrót w ustawieniach kompozytora dla „qterminal -d”.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1160"/>
        <source>Edit bookmark file contents</source>
        <translation>Edycja pliku zakładek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1119"/>
        <source>Enable bookmarks</source>
        <translation>Włącz zakładki</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1128"/>
        <source>Bookmark file</source>
        <translation>Plik zakładek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1141"/>
        <source>Find...</source>
        <translation>Znajdź…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1150"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Możesz wskazać położenie swojego pliku zakładek. Ułatwi to synchronizację przez OwnCloud czy Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <source>No scrollbar</source>
        <translation>Nigdzie</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Left</source>
        <translation>Po lewej</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Right</source>
        <translation>Po prawej</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Top</source>
        <translation>Na górze</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Bottom</source>
        <translation>Na dole</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>BlockCursor</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>UnderlineCursor</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>IBeamCursor</source>
        <translation>Pionowa linia</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>No move</source>
        <translation>Nie przewijaj</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to top</source>
        <translation>Przewijanie do góry</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to bottom</source>
        <translation>Przewijanie na dół</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="289"/>
        <source>Examples</source>
        <translation>Przykłady</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="456"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Obrazy (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="558"/>
        <source>Open bookmarks file</source>
        <translation>Otwórz plik zakładek</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="560"/>
        <source>XML files (*.xml)</source>
        <translation>Pliki XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="561"/>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Czy chcesz nadpisać ten plik zakładek?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Nazwa pliku zakładek nie kończy się na „.xml”.
Czy na pewno chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Nie można zapisać zakładek do tego pliku:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="225"/>
        <location filename="../propertiesdialog.cpp" line="342"/>
        <source>System Default</source>
        <translation>Systemowy</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="455"/>
        <source>Choose a background image</source>
        <translation>Wybierz obraz tła</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Zakładki synchronizowane</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="85"/>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Shell No. %1</source>
        <translation>Powłoka %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Close Subterminal</source>
        <translation>Zamknij podterminal</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Are you sure you want to close this subterminal?</source>
        <translation>Czy na pewno chcesz zamknąć ten podterminal?</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="222"/>
        <source>Tab name</source>
        <translation>Nazwa karty</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>New tab name:</source>
        <translation>Nowa nazwa karty:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="243"/>
        <source>Select new tab title color</source>
        <translation>Wybierz nowy kolor tytułu karty</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="272"/>
        <source>Close session</source>
        <translation>Zamknij sesję</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="274"/>
        <source>Change title color</source>
        <translation>Zmień kolor tytułu</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Close tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Are you sure you want to close this tab?</source>
        <translation>Czy na pewno chcesz zamknąć tę kartę?</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Wczytaj sesję</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Lista zapisanych sesji:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Okno główne</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="62"/>
        <source>&amp;Session</source>
        <translation>&amp;Sesja</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="70"/>
        <source>&amp;Actions</source>
        <translation>&amp;Działania</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="75"/>
        <source>&amp;Help</source>
        <translation>Po&amp;moc</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="82"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="87"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="103"/>
        <source>&amp;About...</source>
        <translation>&amp;O programie…</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="108"/>
        <source>About &amp;Qt...</source>
        <translation>O &amp;Qt...</translation>
    </message>
</context>
</TS>
